@@ -7,8 +7,9 @@ use structopt::StructOpt;
 mod cli;
 mod directory_reader;
 mod duplicate_detection;
-mod hashing;
+mod hashing_utilities;
 mod model;
+mod regex_utilities;
 mod reporter;
 
 const ERROR_EXIT_CODE: i32 = 1;
@@ -18,12 +19,10 @@ fn main() {
     let arguments = cli::Arguments::from_args();
     debug!("The command line arguments provided are {:?}.", arguments);
 
-    let raw_files = crate::directory_reader::get_files_in_current_directory();
-    let indexed_files = crate::model::indexed_file::to_indexed_files(
-        arguments.ignore_file_regex,
-        arguments.ignore_line_regex,
-        raw_files,
-    );
+    let raw_files =
+        crate::directory_reader::get_files_in_current_directory(arguments.ignore_file_regex);
+    let indexed_files =
+        crate::model::indexed_file::to_indexed_files(arguments.ignore_line_regex, raw_files);
     let hashed_files = crate::model::hashed_file::to_hashed_files(&indexed_files);
     let duplicates = crate::duplicate_detection::get_all_duplicates(
         arguments.minimum_successive_lines,
