@@ -4,7 +4,7 @@ use super::*;
 
 pub type Duplicates = Vec<Duplicate>;
 
-#[derive(serde::Serialize)]
+#[derive(serde::Serialize, PartialOrd, PartialEq, Ord, Eq)]
 pub struct Duplicate {
     pub file_1: Filename,
     pub file_1_line_range: LineRange,
