@@ -1,9 +1,7 @@
-use std::collections::{BTreeMap, HashMap};
-
 use regex::Regex;
 #[cfg(test)]
 use serde::{Serialize, Serializer};
-use std::process::exit;
+use std::collections::{BTreeMap, HashMap};
 
 use crate::model::raw_file::*;
 
@@ -11,7 +9,6 @@ use super::*;
 
 pub type LineNumberToLine = HashMap<LineNumber, Line>;
 pub type IndexedFiles = BTreeMap<Filename, IndexedFile>;
-pub type Regexes = Vec<Regex>;
 
 #[cfg_attr(test, derive(Serialize))]
 pub struct IndexedFile {
@@ -41,7 +38,7 @@ impl IndexedFile {
         for line in raw_file.lines {
             let trimmed_line = line.trim().to_string();
 
-            if does_not_match_any(&trimmed_line, ignore_line_regexes) {
+            if crate::regex_utilities::does_not_match_any(&trimmed_line, ignore_line_regexes) {
                 line_number_to_line.insert(line_number, trimmed_line);
             }
 
@@ -55,52 +52,21 @@ impl IndexedFile {
     }
 }
 
-pub fn to_indexed_files(
-    ignore_file_regexes: Vec<String>,
-    ignore_line_regexes: Vec<String>,
-    raw_files: RawFiles,
-) -> IndexedFiles {
+pub fn to_indexed_files(ignore_line_regexes: Vec<String>, raw_files: RawFiles) -> IndexedFiles {
     let mut indexed_files = BTreeMap::new();
-    let compiled_ignore_line_regexes = get_regexes(ignore_line_regexes);
-    let compiled_ignore_file_regexes = get_regexes(ignore_file_regexes);
+    let compiled_ignore_line_regexes = crate::regex_utilities::get_regexes(ignore_line_regexes);
 
     for raw_file in raw_files {
-        if does_not_match_any(&raw_file.filename, &compiled_ignore_file_regexes) {
-            let filename = raw_file.filename.clone();
-            let indexed_file = IndexedFile::new(&compiled_ignore_line_regexes, raw_file);
+        let filename = raw_file.filename.clone();
+        let indexed_file = IndexedFile::new(&compiled_ignore_line_regexes, raw_file);
 
-            if !indexed_file.line_number_to_line.is_empty() {
-                indexed_files.insert(filename, indexed_file);
-            }
+        if !indexed_file.line_number_to_line.is_empty() {
+            indexed_files.insert(filename, indexed_file);
         }
     }
 
     indexed_files
 }
 
-fn does_not_match_any(checking: &str, regexes: &[Regex]) -> bool {
-    for regex in regexes {
-        if regex.is_match(checking) {
-            return false;
-        }
-    }
-
-    true
-}
-
-fn get_regexes(regexes: Vec<String>) -> Regexes {
-    regexes.iter().map(|regex| get_regex(regex)).collect()
-}
-
-fn get_regex(regex: &str) -> Regex {
-    match Regex::new(regex) {
-        Ok(regex) => regex,
-        Err(error) => {
-            error!("{:?}", error);
-            exit(crate::ERROR_EXIT_CODE);
-        }
-    }
-}
-
 #[cfg(test)]
 mod tests;
