@@ -2,29 +2,14 @@ use crate::model::raw_file::RawFile;
 
 macro_rules! assert_indexed_files {
     ($snapshot_name:expr, $raw_files:expr) => {
-        assert_indexed_files_base!($snapshot_name, vec![], vec![], $raw_files);
+        assert_indexed_files_with_ignore_line_regex!($snapshot_name, vec![], $raw_files);
     };
 }
 
 macro_rules! assert_indexed_files_with_ignore_line_regex {
     ($snapshot_name:expr, $ignore_line_regex:expr, $raw_files:expr) => {
-        assert_indexed_files_base!($snapshot_name, vec![], $ignore_line_regex, $raw_files);
-    };
-}
-
-macro_rules! assert_indexed_files_with_ignore_file_regex {
-    ($snapshot_name:expr, $ignore_file_regex:expr, $raw_files:expr) => {
-        assert_indexed_files_base!($snapshot_name, $ignore_file_regex, vec![], $raw_files);
-    };
-}
-
-macro_rules! assert_indexed_files_base {
-    ($snapshot_name:expr, $ignore_file_regex:expr, $ignore_line_regex:expr, $raw_files:expr) => {
-        let indexed_files = crate::model::indexed_file::to_indexed_files(
-            $ignore_file_regex,
-            $ignore_line_regex,
-            $raw_files,
-        );
+        let indexed_files =
+            crate::model::indexed_file::to_indexed_files($ignore_line_regex, $raw_files);
 
         // Then
         insta::assert_json_snapshot!($snapshot_name, indexed_files);
@@ -133,24 +118,3 @@ fn test_indexed_file_ignore_line_regex() {
         raw_files
     );
 }
-
-#[test]
-fn test_indexed_file_ignore_file_regex() {
-    // Given
-    let raw_files = vec![RawFile {
-        filename: "ignore_file.stx".to_string(),
-        lines: vec![
-            "line 1".to_string(),
-            "line 2".to_string(),
-            "line 3".to_string(),
-        ],
-    }];
-    let ignore_file_regex = vec!["[.]stx$".to_string()];
-
-    // When/Then
-    assert_indexed_files_with_ignore_file_regex!(
-        "indexed_file_ignore_file_regex",
-        ignore_file_regex,
-        raw_files
-    );
-}
