@@ -1,6 +1,6 @@
 use super::*;
 
-#[derive(serde::Serialize)]
+#[derive(serde::Serialize, PartialOrd, PartialEq, Ord, Eq)]
 pub struct LineRange {
     pub start: LineNumber,
     pub end: LineNumber,
